Documentation of datatoolbox
=======================================

Installation
-----------------

.. toctree::
  :maxdepth: 2
  
  installation
  
  
Getting started
-----------------

.. toctree::
   :maxdepth: 2

   first_steps


Package content:
-----------------

.. toctree::
   :maxdepth: 3

   data_structures
   core
   database
   tools 
   license
   help

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

